@@ -1,6 +1,6 @@
 package Dancer2::FileUtils;
 # ABSTRACT: File utility helpers
-$Dancer2::FileUtils::VERSION = '0.160001';
+$Dancer2::FileUtils::VERSION = '0.160002';
 use strict;
 use warnings;
 
@@ -12,7 +12,7 @@ use Cwd 'realpath';
 use Exporter 'import';
 our @EXPORT_OK = qw(
   dirname open_file path read_file_content read_glob_content
-  path_or_empty set_file_mode normalize_path
+  path_or_empty set_file_mode normalize_path escape_filename
 );
 
 
@@ -87,6 +87,16 @@ sub normalize_path {
     return $path;
 }
 
+sub escape_filename {
+    my $filename = shift or return;
+
+    # based on escaping used in CHI::Driver. Our use-case is one-way,
+    # so we allow utf8 chars to be escaped, but NEVER do the inverse
+    # operation.
+    $filename =~ s/([^A-Za-z0-9_\=\-\~])/sprintf("+%02x", ord($1))/ge;
+    return $filename;
+}
+
 1;
 
 __END__
@@ -101,7 +111,7 @@ Dancer2::FileUtils - File utility helpers
 
 =head1 VERSION
 
-version 0.160001
+version 0.160002
 
 =head1 SYNOPSIS
 
@@ -209,6 +219,14 @@ Returns the content and B<closes the file handle>.
 
 =head2 my $norm_path=normalize_path ($path);
 
+=head2 my $escaped_filename = escape_filename( $filename );
+
+Escapes characters in a filename that may alter a path when concatenated.
+
+  use Dancer2::FileUtils 'escape_filename';
+
+  my $safe = escape_filename( "a/../b.txt" ); # a+2f+2e+2e+2fb+2etxt
+
 =head1 EXPORT
 
 Nothing by default. You can provide a list of subroutines to import.
